<?php

declare(strict_types=1);

namespace Drupal\search_api_field_datasource\Hook;

use Drupal\Core\Hook\Attribute\Hook;
use Drupal\Core\Routing\RouteMatchInterface;

/**
 * Hook implementations for search_api_field_datasource.
 */
class SearchApiFieldDatasourceHooks {

  /**
   * Implements hook_help().
   */
  #[Hook('help')]
  public function help(
    string $route_name,
    RouteMatchInterface $route_match,
  ): ?string {
    switch ($route_name) {
      case 'help.page.search_api_field_datasource':
        $output = '<h2>' . t('About') . '</h2>';
        $output .= '<p>' . t('This module allows the creating a SearchAPI index that is keyed by an Entity field.') . '</p>';
        $output .= '<h2>' . t('Uses') . '</h2>';
        $output .= '<dl>';
        $output .= '<dt>' . t('Strict Backend key requirements') . '</dt>';
        $output .= '<dd>' . t('In some cases your search API backend may have strict key that make it difficult to use entity keys.') . '</dd>';
        $output .= '<dt>' . t('Difficult query semantics') . '</dt>';
        $output .= '<dd>' . t('It may be difficult for a backend to target a specific entity during delete operations because the original entity is missing requiring the datasource to be keyed by a different field.') . '</dd>';
        $output .= '</dl>';
        return $output;
    }
    return NULL;
  }

}
